#
#  PreferenceController.rb
#  RubyRaiseMan
#


require 'osx/cocoa'

class PreferenceController < OSX::NSWindowController
  
  RRMTableBgColorKey = "Table Background Color".freeze
  RRMEmptyDocKey = "Empty Document Flag".freeze
  RRMTableBgColorChanged = "Table Background Color Changed".freeze
  
  ib_outlets :color_well, :checkbox
  
  def init
    initWithWindowNibName("Preferences")
  end
  
  def windowDidLoad
    OSX::NSLog("Nib file is loaded")
    @color_well.setColor(self.table_background_color)
    @checkbox.setState(self.emptyDoc?)
  end
  
  def change_background_color(sender)
    # OSX::NSLog("color changed")
    color = sender.color
    color_as_data = OSX::NSKeyedArchiver.archivedDataWithRootObject(color)
    defaults = OSX::NSUserDefaults.standardUserDefaults
    defaults.setObject_forKey(color_as_data, RRMTableBgColorKey)
    
    # Bundle the color information into the notification as a dictionary
    color_info = OSX::NSDictionary.dictionaryWithObject_forKey(color, RRMTableBgColorKey)
    notification = OSX::NSNotification.notificationWithName_object_userInfo(RRMTableBgColorChanged, self, color_info)
    
    notification_center = OSX::NSNotificationCenter.defaultCenter
    notification_center.postNotification(notification)
  end
  
  def change_new_empty_doc(sender)
    # OSX::NSLog("checkbox changed")
    (OSX::NSUserDefaults.standardUserDefaults).setBool_forKey(sender.state, RRMEmptyDocKey)
  end
  
  def table_background_color
    defaults = OSX::NSUserDefaults.standardUserDefaults
    color_as_data = defaults.objectForKey(RRMTableBgColorKey)
    OSX::NSKeyedUnarchiver.unarchiveObjectWithData(color_as_data)
  end
  
  def emptyDoc?
    defaults = OSX::NSUserDefaults.standardUserDefaults
    defaults.boolForKey(RRMEmptyDocKey)
  end
  
  def reset_to_defaults (sender)
    defaults = OSX::NSUserDefaults.standardUserDefaults
    keys = defaults.dictionaryRepresentation.allKeys
    keys.each {|key| defaults.removeObjectForKey(key) }
    reload_user_defaults
  end
  
  private
  
  def reload_user_defaults
    defaults = OSX::NSUserDefaults.standardUserDefaults
    defaults.extend OSX::RCDictionaryAttachment
    # this works because NSUserDefault has objectForKey method
    # so when you call defaults[some_key] you are calling defaults.objectForKey
    color_as_data = defaults[RRMTableBgColorKey] 
	  color = OSX::NSKeyedUnarchiver.unarchiveObjectWithData(color_as_data)
    @color_well.setColor(color)
    @checkbox.setState(defaults[RRMEmptyDocKey])
    
    notification_center = OSX::NSNotificationCenter.defaultCenter
    notification_center.postNotificationName_object(RRMTableBgColorChanged, self)
  end
  
end
